Description Usage Format Source
A dataset on monthly medical and recreational marijuana sales from 2014 to 2017 in Denver, Colorado
1 |
A data frame with 90 observations and 4 variables.
YEAR Years of marijuana sales (2014-2017))
MONTH Months of marijuana sales
GROSS_SALES_TYPE Medical or recreational sales of marijuana
GROSS_SALES Total gross sales of marijuana (US dollars)
Data collected by City and County of Denver Office of Marijuana Policy and provided by City of Denver Open Data Catalog and used in the "MATH 241" create an r data package project. See also < http://data.denvergov.org>
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.